/*
 * caller id related functions
 *
 * This file is part of ANT (Ant is Not a Telephone)
 *
 * Copyright 2002 Roland Stigge
 *
 */

/* GTK */
#include <gtk/gtk.h>

/* own header files */
#include "session.h"

enum call_type_t {
  CALL_IN,
  CALL_OUT
};

void cid_toggle_cb(GtkWidget *widget, gpointer data, guint action);
GtkWidget *cid_new(struct session_t *session);
void cid_add_line(struct session_t *session,
		  enum call_type_t ct, gchar *from, gchar *to);
void cid_add_data(struct session_t *session, gchar *from);
void cid_call_finished(struct session_t *session, gchar *message);
void cid_normalize(struct session_t *session);
void cid_add_saved_line(struct session_t *session, char *date, char *type,
			char *from, char *to, char *duration);
